Struct actix_web_utils::dtos::message::MessageResource
source · [−]Expand description
This is for sending errors back from requests conveniently. This struct contains an optional key just in case you want to deal with internationalization. It was left as optional just in case you don’t have the time to yet…
Fields
key: Option<String>message: StringImplementations
sourceimpl MessageResource
impl MessageResource
pub fn new_empty() -> MessageResource
pub fn new_from_str(msg: &str) -> MessageResource
sourcepub fn new_from_err<E: Display>(error: E) -> MessageResource
pub fn new_from_err<E: Display>(error: E) -> MessageResource
Just takes any error that implements display (Has a .to_string() method)
pub fn new(key: &str, msg: &str) -> MessageResource